@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2020 Google LLC
+# Copyright 2022 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,7 +16,7 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core.client_options import ClientOptions
@@ -227,13 +227,13 @@ class IndexEndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Creates an IndexEndpoint.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_create_index_endpoint():
+            async def sample_create_index_endpoint():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 index_endpoint = aiplatform_v1beta1.IndexEndpoint()
@@ -249,7 +249,7 @@ class IndexEndpointServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -321,7 +321,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -345,13 +350,13 @@ class IndexEndpointServiceAsyncClient:
     ) -> index_endpoint.IndexEndpoint:
         r"""Gets an IndexEndpoint.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_get_index_endpoint():
+            async def sample_get_index_endpoint():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.GetIndexEndpointRequest(
@@ -359,7 +364,7 @@ class IndexEndpointServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.get_index_endpoint(request=request)
+                response = await client.get_index_endpoint(request=request)
 
                 # Handle the response
                 print(response)
@@ -421,7 +426,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -437,13 +447,13 @@ class IndexEndpointServiceAsyncClient:
     ) -> pagers.ListIndexEndpointsAsyncPager:
         r"""Lists IndexEndpoints in a Location.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_list_index_endpoints():
+            async def sample_list_index_endpoints():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.ListIndexEndpointsRequest(
@@ -454,7 +464,7 @@ class IndexEndpointServiceAsyncClient:
                 page_result = client.list_index_endpoints(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -516,12 +526,20 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListIndexEndpointsAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -539,13 +557,13 @@ class IndexEndpointServiceAsyncClient:
     ) -> gca_index_endpoint.IndexEndpoint:
         r"""Updates an IndexEndpoint.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_update_index_endpoint():
+            async def sample_update_index_endpoint():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 index_endpoint = aiplatform_v1beta1.IndexEndpoint()
@@ -556,7 +574,7 @@ class IndexEndpointServiceAsyncClient:
                 )
 
                 # Make the request
-                response = client.update_index_endpoint(request=request)
+                response = await client.update_index_endpoint(request=request)
 
                 # Handle the response
                 print(response)
@@ -628,7 +646,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -644,13 +667,13 @@ class IndexEndpointServiceAsyncClient:
     ) -> operation_async.AsyncOperation:
         r"""Deletes an IndexEndpoint.
 
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_delete_index_endpoint():
+            async def sample_delete_index_endpoint():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.DeleteIndexEndpointRequest(
@@ -662,7 +685,7 @@ class IndexEndpointServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -736,7 +759,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -763,14 +791,13 @@ class IndexEndpointServiceAsyncClient:
         DeployedIndex within it.
         Only non-empty Indexes can be deployed.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_deploy_index():
+            async def sample_deploy_index():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 deployed_index = aiplatform_v1beta1.DeployedIndex()
@@ -787,7 +814,7 @@ class IndexEndpointServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -863,7 +890,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -890,14 +922,13 @@ class IndexEndpointServiceAsyncClient:
         DeployedIndex from it, and freeing all resources it's
         using.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_undeploy_index():
+            async def sample_undeploy_index():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 request = aiplatform_v1beta1.UndeployIndexRequest(
@@ -910,7 +941,7 @@ class IndexEndpointServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -986,7 +1017,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -1012,14 +1048,13 @@ class IndexEndpointServiceAsyncClient:
         r"""Update an existing DeployedIndex under an
         IndexEndpoint.
 
-
-        .. code-block::
+        .. code-block:: python
 
             from google.cloud import aiplatform_v1beta1
 
-            def sample_mutate_deployed_index():
+            async def sample_mutate_deployed_index():
                 # Create a client
-                client = aiplatform_v1beta1.IndexEndpointServiceClient()
+                client = aiplatform_v1beta1.IndexEndpointServiceAsyncClient()
 
                 # Initialize request argument(s)
                 deployed_index = aiplatform_v1beta1.DeployedIndex()
@@ -1036,7 +1071,7 @@ class IndexEndpointServiceAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -1114,7 +1149,12 @@ class IndexEndpointServiceAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
