@@ -561,5 +561,9 @@ class PipelineServiceGrpcTransport(PipelineServiceTransport):
     def close(self):
         self.grpc_channel.close()
 
+    @property
+    def kind(self) -> str:
+        return "grpc"
+
 
 __all__ = ("PipelineServiceGrpcTransport",)
