@@ -64,6 +64,9 @@ class BatchPredictionJob(proto.Message):
             Starting this job has no impact on any existing deployments
             of the Model and their resources. Exactly one of model and
             unmanaged_container_model must be set.
+        model_version_id (str):
+            Output only. The version ID of the Model that
+            produces the predictions via this job.
         unmanaged_container_model (google.cloud.aiplatform_v1beta1.types.UnmanagedContainerModel):
             Contains model information necessary to perform batch
             prediction without requiring uploading to model registry.
@@ -192,7 +195,7 @@ class BatchPredictionJob(proto.Message):
         update_time (google.protobuf.timestamp_pb2.Timestamp):
             Output only. Time when the BatchPredictionJob
             was most recently updated.
-        labels (Sequence[google.cloud.aiplatform_v1beta1.types.BatchPredictionJob.LabelsEntry]):
+        labels (Mapping[str, str]):
             The labels with user-defined metadata to
             organize BatchPredictionJobs.
             Label keys and values can be no longer than 64
@@ -414,6 +417,10 @@ class BatchPredictionJob(proto.Message):
         proto.STRING,
         number=3,
     )
+    model_version_id = proto.Field(
+        proto.STRING,
+        number=30,
+    )
     unmanaged_container_model = proto.Field(
         proto.MESSAGE,
         number=28,
